@@ -7,7 +7,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '1.33';
+$VERSION = '1.402';
 
 use Carp qw(croak);
 
@@ -48,6 +48,13 @@ sub column($$)
     return $self->table($table)->column($column);
 }
 
+sub _gen_access_fastpath($)
+{
+    my ( $self, $table ) = @_;
+
+    return $self->table($table)->_gen_access_fastpath();
+}
+
 package SQL::Eval::Table;
 
 use Carp qw(croak);
@@ -84,6 +91,21 @@ sub column_num($) { $_[0]->{col_nums}->{ $_[1] }; }
 sub col_nums()    { $_[0]->{col_nums} }
 sub col_names()   { $_[0]->{col_names}; }
 
+sub _gen_access_fastpath($)
+{
+    my ($self) = @_;
+
+    if (     $self->can("column") == SQL::Eval::Table->can("column")
+         and $self->can("column_num") == SQL::Eval::Table->can("column_num") )
+    {
+        return sub { $self->{row}->[ $self->{col_nums}->{ $_[0] } ] };
+    }
+    else
+    {
+        return sub { $self->column( $_[0] ) };
+    }
+}
+
 sub capability($)
 {
     my ( $self, $capname ) = @_;
@@ -225,6 +247,12 @@ This is equivalent to and a shorthand for
 
     $col = $eval->table('foo')->column('id');
 
+=item _gen_access_fastpath
+
+Return a subroutine reference for fast accessing columns for read-only
+access. This routine simply returns the C<_gen_access_fastpath> of the
+referenced table.
+
 =back
 
 
@@ -260,6 +288,14 @@ created from C<col_names>.
 
 Hash reference containing additional capabilities.
 
+=item _gen_access_fastpath
+
+Return a subroutine reference for fast accessing columns for read-only
+access. When the instantiated object doesn't provide own methods for
+C<column> and C<column_num> a subroutine reference is returned which
+directly access the internal data structures. For all other cases a
+subroutine directly calling C<< $self->column($_[0]) >> is returned.
+
 =back
 
 =item row
