@@ -12,7 +12,7 @@ use Data::Dumper;
 use Params::Util qw(_HASH _ARRAY0 _INSTANCE);
 use Scalar::Util qw(blessed weaken);
 
-our $VERSION = '1.33';
+our $VERSION = '1.402';
 
 my %oplist = (
                '='       => 'Equal',
@@ -105,7 +105,7 @@ sub buildCondition
     elsif ( defined( $pred->{type} ) )
     {
         my $type = uc( $pred->{type} );
-        if ( ( $type eq 'STRING' ) || ( $type eq 'NUMBER' ) )
+        if ( $type =~ m/^(?:STRING|NUMBER|BOOLEAN)$/ )
         {
             $term = SQL::Statement::ConstantTerm->new( $self->{OWNER}, $pred->{value} );
         }
